@@ -1,4 +1,4 @@
-//@line 38 "/home/karma/src/build/build/toolkit/mozapps/downloads/content/helperApps.js"
+//@line 38 "/home/karma/src/build/toolkit/mozapps/downloads/content/helperApps.js"
 
 var Cc = Components.classes;
 var Ci = Components.interfaces;
@@ -561,7 +561,13 @@ HandlerOverride.prototype = {
   
   set appDisplayName(aDisplayName)
   {
-    this.changeMIMEStuff(APP_URI(this.mimeType), "prettyName", aDisplayName);
+    if (aDisplayName)
+      this.changeMIMEStuff(APP_URI(this.mimeType), "prettyName", aDisplayName);
+    else {
+      var currentValue = this.getLiteralForContentType(APP_URI(this.mimeType), "prettyName");
+      this.unassertMIMEStuff(APP_URI(this.mimeType), "prettyName", currentValue);
+    }
+
     return aDisplayName;
   },
   
@@ -572,7 +578,13 @@ HandlerOverride.prototype = {
   
   set appPath(aAppPath)
   {
-    this.changeMIMEStuff(APP_URI(this.mimeType), "path", aAppPath);
+    if (aAppPath)
+      this.changeMIMEStuff(APP_URI(this.mimeType), "path", aAppPath);
+    else {
+      var currentValue = this.getLiteralForContentType(APP_URI(this.mimeType), "path");
+      this.unassertMIMEStuff(APP_URI(this.mimeType), "path", currentValue);
+    }
+
     return aAppPath;
   },
 
